use strict;
use warnings;

use Test::More tests => 31;
use IO::Handle;

use_ok "Text::CSV::Slurp";

my $file = "data/simple.csv";

{
  diag "Pass in a filehandle";

  my $io = new IO::Handle;
  open($io, "<$file");
  
  my $data = Text::CSV::Slurp->load(filehandle => $io);
  
  _check_response($data);
  
}

{
  diag "Pass in a filename";

  my $data = Text::CSV::Slurp->load(file => $file);
  _check_response($data);
  
}

{
  diag "Pass in a string";
  my $io = new IO::Handle;
  open($io, "<$file");
  my $string;
  while (<$io>) {
    $string .= $_;
  }

  my $data = Text::CSV::Slurp->load(string => $string);
  _check_response($data);
}


sub _check_response {
  my $data = shift;

  is ref($data), 'ARRAY', 'Returns an array';
  is scalar @{$data}, 2, 'Right number of entries';

  my %expect = (  age         => qr/^\d+$/,
                  name        => qr/^\w+|\s+$/,
                  description => qr/^\w+|\s+|\.|\,$/,
                  id          => qr/^\d+$/,
               );

  for my $entry (@$data) {
    while ( my($key,$pattern) = each(%expect) ) {
      ok $entry->{$key} =~ /$pattern/, "$key looks okay";
    }
  }
}